/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007, 2008. All Rights Reserved. 
 * 
 * Note to U.S. Government Users Restricted Rights:  Use, 
 * duplication or disclosure restricted by GSA ADP Schedule 
 * Contract with IBM Corp.
 *******************************************************************************/
// Helper method to call rest service
function callRestService(methodName, args, callbackObject, successMethodName, failureMethodName) {
    dojo.require("com.ibm.team.repository.web.transport.ServiceRequest");
    dojo.require("com.ibm.team.repository.web.transport.ServiceResponseHandler");
    dojo.require("com.ibm.team.repository.web.transport.TeamServerClient");
    var responseHandler = new com.ibm.team.repository.web.transport.ServiceResponseHandler(
        callbackObject, successMethodName, failureMethodName);
    var serviceRequest = new com.ibm.team.repository.web.transport.ServiceRequest(
            "com.ibm.team.reports.common.internal.service.IReportRestService",
            methodName,
            args);
    com.ibm.team.repository.web.transport.TeamServerClient.invokeService(
        serviceRequest,
        responseHandler);
}

function updateReport(useInitialValues, warnIfMissingParameters) {
	if (useInitialValues == null || useInitialValues == undefined) useInitialValues = false;
	if (warnIfMissingParameters == null || warnIfMissingParameters == undefined) warnIfMissingParameters = true;
    if (!useInitialValues && !hasAllRequiredParameters()) {
    	if (warnIfMissingParameters) {
    		// Tell the user and don't do anything.
	        alert("Please enter values for all required parameters");
	    } else {
	    	// Display an empty page.
	    	var div = document.getElementById("renderedReportDiv");
	    	div.innerHTML = "";
	    }
        return;
    }
    
    var obj = {
        mySuccessFunction: mySuccessFunction,
        myErrorFunction: myErrorFunction
    };
    
    // Install a loading indicator before sending the request
    var div = document.getElementById("loadingDiv");
    div.innerHTML = "<div class=\"loading\">Loading...</div>";
    // Blank out the current report as well
    div = document.getElementById("renderedReportDiv");
    
    var oldParameterValues = null;
    if (useInitialValues && useInitialValues == true) {
    	oldParameterValues = initialParameterValues;
    } else {
    	oldParameterValues = allParameterValues;
    }
	var newParameters = prepareParameters(allParameterValues);    

    div.innerHTML = "";
    var args = {
        reportUUID: reportUUID,
        embeddable: true,
        parameterName: newParameters.names,
        parameterValue: newParameters.values,
        webui: true,
        showArchived: showArchived
    };
    callRestService("postRenderReport", 
        args, obj, 
        "mySuccessFunction", "myErrorFunction");
}


function mySuccessFunction(args) {
    // Insert the HTML into the report div
	if (navigator.appVersion.indexOf("MSIE")!=-1) {
		// Insert innerHTML directly. That, coupled with defer tags
		// on the scripts, causes new Javascript to be executed properly.
        var div = document.getElementById("renderedReportDiv");
        div.innerHTML = args;
	} else {
		// Create a new node and appendChild so javascript gets executed.
		var newNode = document.createElement('div');
		newNode.innerHTML = args;
        var div = document.getElementById("renderedReportDiv");
		while (div.firstChild) {
		    div.removeChild(div.firstChild);
		}
		div.appendChild(newNode);
	} 
    div = document.getElementById("loadingDiv");
    div.innerHTML = "";
}

function myErrorFunction(errorType, errorMessage) {
	alert("Error: " + errorType.message);
}

function postSave() {
	var nameWidget = document.getElementById("saveAsName");
	net.jazz.ajax.ui.PlatformUI.getWorkbench().setTitle("Report: " + nameWidget.value);
	reportController.refreshNavigator();
}

function postSetAsDefault(defaultQuery) {
	reportController.setDefaultQuery(defaultQuery);
}

